@@ -6,10 +6,11 @@ def bar(progress, total, icon='█', begin='Downloading', show_percent=True):
     Be sure to print a ('\\n') after running the bar function!
     You can find out why ;)
     '''
-    percent = 100 * (progress / float(total))
-    bar = icon * int(percent) + '-' * (100 - int(percent))
+    percent = 50 * (progress / float(total))
+    some = percent - 50
+    bar = icon * int(percent) + '-' * (50 - int(percent))
     if show_percent == True:
-        print(f"\r{begin} |{bar}| {percent:.2f}%", end="")
+        print(f"\r{begin} |{bar}| {50 + percent:.2f}%", end="")
     else:
         print(f"\r{begin} |{bar}|", end="")
 
@@ -20,3 +21,10 @@ def rotate(begin = 'Downloading', sleep_value = 0.1):
         sleep(sleep_value)
         ting = i
         print(f'\r{begin} {ting}', end='\r')
+
+import math
+numbers = [x * 5 for x in range(100, 2000)]
+list = []
+for i, a in enumerate(numbers):
+    list.append(math.factorial(i))
+    bar(i + 1, len(numbers))
\ No newline at end of file
